@@ -13,7 +13,7 @@ class PythonQTWrapperSink : public QObject, public PluginAction
 {
     Q_OBJECT
 public:
-    PythonQTWrapperSink(const PluginInterface *interface, PyObject* sinkInstance);
+    PythonQTWrapperSink(const PluginInterface *interface, PyObject* sinkInstance/*, QObject *obj, QWidget *widg*/);
     QString getName();
     QString getText();
     QImage getImage();
@@ -23,10 +23,11 @@ public:
 private:
     QString sinkBarcodeType;
     QString sinkBarcodeData;
-
     QString pluginName;
 
     PyObject* sinkInstance;
+    //QObject* obj;
+    //QWidget *widg;
 
 private slots:
     void barcodeAnalysed(QString barcodeType, QString barcodeData);
